// Xmas Contest 2014
// Output Checker for "Fake Distribution"
// Author: hos <hos@hos.ac>

#include <stdio.h>
#include <stdlib.h>
#include <string>
#include <vector>

using std::string;
using std::vector;

const int kBufferSize = 10;

// Show message to the contestant, tell CMS that the score is zero, and exit.
void ReportError(const char *message) {
  fprintf(stderr, "%s\n", message);
  printf("0.00\n");
  exit(0);
}

// Return true if the format of the file is correct.
bool ReadLines(int num_cases, FILE *file, vector<string> *lines) {
  lines->clear();
  for (int t = 0; ; ++t) {
    char buffer[kBufferSize];
    if (!fgets(buffer, kBufferSize, file)) {
      if (t < num_cases) {
        return false;
      }
      break;
    }
    if (t >= num_cases) {
      return false;
    }
    string line = buffer;
    if (line.length() >= 2 && line.substr(line.length() - 2) == "\r\n") {
      line = line.substr(0, line.length() - 2);
    } else if (line.length() >= 1 && line.substr(line.length() - 1) == "\n") {
      line = line.substr(0, line.length() - 1);
    } else {
      return false;
    }
    lines->push_back(line);
  }
  return true;
}

int main(int argc, char **argv) {
  if (argc <= 3) {
    fprintf(stderr,
            "[SYSTEM ERROR] Usage: checker [input] [answer] [output]\n");
    exit(1);
  }

  // Read the number of testcases.
  FILE *input = fopen(argv[1], "r");
  if (!input) {
    fprintf(stderr, "[SYSTEM ERROR] Cannot open the input file.\n");
    exit(1);
  }
  int num_cases;
  if (1 != fscanf(input, "%d", &num_cases)) {
    fprintf(stderr, "[SYSTTEM ERROR] The input file has an error.\n");
    exit(1);
  }
  fclose(input);

  // Read the correct answer.
  vector<string> lines_answer;
  FILE *answer = fopen(argv[2], "r");
  if (!answer) {
    fprintf(stderr, "[SYSTEM ERROR] Cannot open the answer file.\n");
    exit(1);
  }
  if (!ReadLines(num_cases, answer, &lines_answer)) {
    fprintf(stderr, "[SYSTTEM ERROR] The answer file has an error.\n");
    exit(1);
  }
  fclose(answer);

  // Read the contestant's output.
  vector<string> lines_output;
  FILE *output = fopen(argv[3], "r");
  if (!output) {
    fprintf(stderr, "[SYSTEM ERROR] Cannot open the output file.\n");
    exit(1);
  }
  if (!ReadLines(num_cases, output, &lines_output)) {
    ReportError("[FORMAT ERROR]");
  }
  fclose(output);

  // Compare the answer and the output.
  int num_agree = 0;
  for (int t = 0; t < num_cases; ++t) {
    if (lines_answer[t] == lines_output[t]) {
      ++num_agree;
    }
  }
#ifdef LOCAL_TEST
  fprintf(stderr, "%d/%d\n", num_agree, num_cases);
#endif

  // OK if num_agree >= (4/5) * num_cases
  if (num_agree * 5 >= num_cases * 4) {
    fprintf(stderr, "[ACCEPTED]\n");
    puts("1.00");
  } else {
    fprintf(stderr, "[WRONG ANSWER]\n");
    puts("0.00");
  }

  return 0;
}
